---
name: "❓ Question"
about: "Ask a question about this project 📚"
title: ''
labels: question
assignees:
---

## Checklist

<!-- Mark with an `x` all the checkboxes that apply (like `[x]`) -->

- [ ] I have searched the project's issues for duplicates.
- [ ] I have searched the project's documentation.

## :question: Question

<!-- What is your question -->

How can ..?

## :paperclip: Additional Context

<!-- Add any other context or screenshots about the feature request here. -->
